clear all

% Note:
% momentum unit of π/L0 with L0 ≈ 27.9 nm
%=========================================
% In order to obtain figure 3(e),(f),(g), use nplot = 2, 4 or 6
nplot = 2;

if nplot ==  2; Zn = '_AB_'; Ec = '980'; pp = 4; nk = 60; end
if nplot ==  4; Zn = '_SP_'; Ec = '980'; pp = 4; nk = 60; end
if nplot ==  6; Zn = '_AA_'; Ec = '980'; pp = 4; nk = 60; end

M = 2*nk;

fname = ['BandMap_n1m65',Zn,'Ene',Ec,'.dat']; a = load(fname);

b = [];
for p=1:M
  tmp = a((p-1)*M+1:p*M,:); tmp = sortrows(tmp,2); b = [b tmp(:,pp)];
end

% variables x ≡ κ1 = k∙a1, y ≡ κ2 = k∙a2
% =======================================
y = tmp(:,2); x = [0.5-nk:1:nk-0.5]'/nk; 
[X0,Y0] = meshgrid(x,y); % κ1, κ2 grid

% repeat periodically
% =====================
X0 = [X0-4 X0-2 X0 X0+2 X0+4]; Y0 = [Y0 Y0 Y0 Y0 Y0]; b = [b b b b b];
X0 = [X0; X0; X0; X0; X0]; Y0 = [Y0-4; Y0-2; Y0; Y0+2; Y0+4]; b = [b; b; b; b; b];
kx = (X0+Y0)/sqrt(3); ky = X0-Y0; % kx, ky grid

% Reciprocal vectors in unit of π/L0
% ====================================
v1 = [2/sqrt(3) 2]; v2 = [2/sqrt(3) -2]; %Reciprocal vectors
K1 = (v1-v2)/3; K2 = (2*v1+v2)/3; K3 = (v1+2*v2)/3;
rc = [K1; K2; K3; -K1; -K2; -K3; K1]; % first BZ zone 

figure('position',[600 200 1200 800]);

ang = -30;
kxr = cosd(ang)*kx - sind(ang)*ky;
kyr = sind(ang)*kx + cosd(ang)*ky;

output = pcolor(kxr,kyr,b); shading interp;
axis equal 
colormap(hot)
lim = 2.8  % crop limit
xlim([-lim lim]); ylim([-lim lim])
axis off
h = colorbar; set(h,'FontSize',24,'FontName','Times','FontWeight','bold');
